/*
._onactive(bool)
*/
_me = obj_tab.prototype;
function obj_tab(){};

_me.__constructor = async function(bFirst){

	var me = this;

	this.__eLi = mkElement('li',{id:this._parent._pathName+"/"+this._name, className: this._css || ''}); //ID is for automatic testing

	this.__eLi.onmousedown = function(e){
		e.preventDefault();
		e.stopPropagation();

		if (!me._isActive){
			me._active(null, true);

			if (gui.telemetry)
				gui.telemetry._add({id:this.id, type: me._parent._type});
		}
		else{
			//Execute handlers
			if (me._ondeactive) me._ondeactive();
			me.__exeEvent('ondeactive',null,{"owner":me});
		}
	};
	this.__eLi.oncontextmenu = function(e){
		if (me._oncontext)
			me._oncontext(e);

		return false;
	};

	var elm = this._parent._getAnchor('links');

	if (bFirst && elm.firstChild)
		elm.insertBefore(this.__eLi, elm.firstChild);
	else
		elm.appendChild(this.__eLi);

	if (elm.childElementCount === 1) {
		this._parent._main.classList.add('noheader');
	} else {
		this._parent._main.classList.remove('noheader');
	}
};

/**
 * @Brief: set TITLE for tab
 * @Note predelat na _title() a _text()
 **/
_me._value = function(v,bNoLang){
	if (v){
		this.__tabTitle = v;
		this.__eLi.innerHTML = '<span class="mask">'+ (bNoLang?v:getLang(v)) +'</span><span>'+ (bNoLang?v:getLang(v)) +'</span>';
	}
	else
	    return this.__tabTitle || '';
};

_me._incorrect = function(bError) {
	if (bError)
		addcss(this.__eLi,'error');
	else
		removecss(this.__eLi,'error');
};
